@@ -49,22 +49,8 @@ LastGoWH::LastGoWH(QWidget *parent) :
     trackScrobbled = false;
 }
 
-void LastGoWH::requestReplied(QMap<QString, QString> reply)
-{
-    if(reply["status"] == "ok")
-    {
-        qDebug() << reply["status"];
-    }
-    else if(reply["status"] == "failed")
-    {
-        qDebug() << reply["error"];
-        qDebug() << reply["message"];
-    }
-}
-
 void LastGoWH::radioGetPlaylistReplied(QList<LastfmTrack *> tracks)
 {
-    qDebug() << "New Playlist...";
     playlistTracks = tracks;
     playListIndex = 0;
 
@@ -73,6 +59,15 @@ void LastGoWH::radioGetPlaylistReplied(QList<LastfmTrack *> tracks)
             playTrack(playListIndex);
 }
 
+void LastGoWH::radioGetPlaylistErrorReplied(QMap<QString, QString> reply)
+{
+    ui->statusLabel->setText(reply["message"]);
+    isPlaying = false;
+
+    if(reply["error"] == "9")
+        sk = "";
+}
+
 LastGoWH::~LastGoWH()
 {
     saveSettings();
@@ -145,11 +140,11 @@ void LastGoWH::initializeMediaPlayer()
     playlist = new QMediaPlaylist;
 
     // hack to make things work with maemo qt-mobility version
-    #if defined(Q_WS_MAEMO_5)
-        playlist->setMediaObject(player);
-    #else
+    //#if defined(Q_WS_MAEMO_5)
+    //    playlist->setMediaObject(player);
+    //#else
         player->setPlaylist(playlist);
-    #endif
+    //#endif
 }
 
 void LastGoWH::showSettingsDialog()
@@ -158,6 +153,8 @@ void LastGoWH::showSettingsDialog()
     dialog.setWindowTitle("Settings");
     dialog.showNormal();
     dialog.exec();
+
+    ac->authGetMobileSession(username, password);
 }
 
 void LastGoWH::setUsername(QString user)
@@ -242,6 +239,7 @@ void LastGoWH::connectSlots()
     connect(ac, SIGNAL(scrobblerHandshakeData(QMap<QString,QString>)), this, SLOT(scrobblerHandshakeReplied(QMap<QString,QString>)));
     connect(ac, SIGNAL(scrobblerPlayingData(QString)), this, SLOT(scrobblerPlayingReplied(QString)));
     connect(ac, SIGNAL(scrobblerSubmissionData(QString)), this, SLOT(scrobblerSubmissionReplied(QString)));
+    connect(ac, SIGNAL(radioGetPlaylistError(QMap<QString,QString>)), this, SLOT(radioGetPlaylistErrorReplied(QMap<QString,QString>)));
 }
 
 void LastGoWH::authGetMobileSessionReplied(QMap<QString, QString> reply)
@@ -258,6 +256,8 @@ void LastGoWH::authGetMobileSessionReplied(QMap<QString, QString> reply)
         }
         else
         {
+            ui->playStopButton->setEnabled(true);
+
             if(isTuning)
             {
                 isGettingPlayList = true;
@@ -271,8 +271,6 @@ void LastGoWH::authGetMobileSessionReplied(QMap<QString, QString> reply)
     else if(reply["status"] == "failed")
     {
         ui->statusLabel->setText(reply["message"]);
-        qDebug() << reply["error"];
-        qDebug() << reply["message"];
     }
 }
 
@@ -290,41 +288,42 @@ void LastGoWH::setPlayButtonToStop()
 
 void LastGoWH::playTrack(int i)
 {
-    qDebug() << "Track Index: " + QString::number(i);
-    qDebug() << "Track Number: " + QString::number(playlistTracks.count());
-
-    setPlayButtonToStop();
-
-    if(playlistTracks[i]->Image == "")
-        ui->trackImage->setPixmap(QPixmap(":/images/images/vinile.jpg"));
-    else
+    if(i < playlistTracks.count())
     {
-        manager = new QNetworkAccessManager(this);
-        connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(imageRequestReplied(QNetworkReply*)));
+        ui->statusLabel->setText("");
+        setPlayButtonToStop();
 
-        QNetworkRequest request;
-        request.setUrl(playlistTracks[i]->Image);
-        request.setRawHeader("User-Agent", "LastGo 1.0");
-        manager->get(request);
+        if(playlistTracks[i]->Image == "")
+            ui->trackImage->setPixmap(QPixmap(":/images/images/vinile.jpg"));
+        else
+        {
+            manager = new QNetworkAccessManager(this);
+            connect(manager, SIGNAL(finished(QNetworkReply*)), this, SLOT(imageRequestReplied(QNetworkReply*)));
+
+            QNetworkRequest request;
+            request.setUrl(playlistTracks[i]->Image);
+            request.setRawHeader("User-Agent", "LastGo 1.0");
+            manager->get(request);
+        }
+
+        ui->titleDataLabel->setText(playlistTracks[i]->Title);
+        ui->albumDataLabel->setText(playlistTracks[i]->Album);
+        ui->artistDataLabel->setText(playlistTracks[i]->Creator);
+        ui->progressBar->setMaximum(playlistTracks[i]->Duration.toInt());
+        trackDuration = playlistTracks[i]->Duration.toInt();
+
+        playlist->clear();
+        playlist->addMedia(QUrl(playlistTracks[i]->Location));
+
+        isSkipping = false;
+        player->play();
+        ui->nextTrackButton->setEnabled(true);
+
+        if(scrobblingSession == "")
+            scrobblerHandshake();
+        else
+            scrobblerPlaying();
     }
-
-    ui->titleDataLabel->setText(playlistTracks[i]->Title);
-    ui->albumDataLabel->setText(playlistTracks[i]->Album);
-    ui->artistDataLabel->setText(playlistTracks[i]->Creator);
-    ui->progressBar->setMaximum(playlistTracks[i]->Duration.toInt());
-    trackDuration = playlistTracks[i]->Duration.toInt();
-
-    playlist->clear();
-    playlist->addMedia(QUrl(playlistTracks[i]->Location));
-
-    isSkipping = false;
-    player->play();
-    ui->nextTrackButton->setEnabled(true);
-
-    if(scrobblingSession == "")
-        scrobblerHandshake();
-    else
-        scrobblerPlaying();
 }
 
 void LastGoWH::nextButtonClicked()
@@ -407,8 +406,6 @@ void LastGoWH::radioTuneReplied(QMap<QString, QString> reply)
 {
     if(reply["status"] == "ok")
     {
-        qDebug() << reply["status"];
-
         if(isGettingPlayList)
         {
             isGettingPlayList = false;
@@ -417,9 +414,7 @@ void LastGoWH::radioTuneReplied(QMap<QString, QString> reply)
     }
     else if(reply["status"] == "failed")
     {
-        qDebug() << reply["error"];
-        qDebug() << reply["message"];
-        ui->statusLabel->setText("Error: " + reply["error"]);
+        ui->statusLabel->setText("Error: " + reply["message"]);
     }
 }
 
@@ -480,10 +475,6 @@ void LastGoWH::scrobblerHandshakeReplied(QMap<QString, QString> reply)
         scrobblingPlayingUrl = reply["playing_url"];
         scrobblingSubmissionUrl = reply["submission_url"];
 
-        qDebug() << scrobblingSession;
-        qDebug() << scrobblingPlayingUrl;
-        qDebug() << scrobblingSubmissionUrl;
-
         if(isPlaying)
             scrobblerPlaying();
     }
